// Import necessary hooks and functions from React and D3 libraries
import React, { useState, useEffect } from 'react';
import { json } from 'd3';

// Import functions from the topojson library to convert TopoJSON to GeoJSON
import { feature, mesh } from 'topojson';

// URL of the TopoJSON file containing information about Gujarat state
const jsonUrl =
  'https://gist.githubusercontent.com/GaddamThanmayeeReddy/2fa87176129b5abd6f10921bc3b7ce35/raw/b6bc3eee386ac990e09876f582503934413757b2/gujarat.json';

// Custom hook to load and prepare the TopoJSON data
export const useData = () => {
  // State hook to hold the processed data
  const [data, setData] = useState(null);

  // Log the current state of 'data' to the console - useful for debugging
  console.log(data);

  // Effect hook to perform side effects in the component - in this case, data fetching
  useEffect(() => {
    // Fetch the TopoJSON data from the specified URL
    json(jsonUrl).then((topojsonData) => {
      // Once data is fetched, convert it to GeoJSON format for the landmasses
      // and calculate the interior borders between regions within the data.
      setData({
        land: feature(
          topojsonData, // The TopoJSON data
          topojsonData.objects['gujarat'], // The specific object within the TopoJSON to be converted to GeoJSON
        ),
        interiors: mesh(
          topojsonData, // The TopoJSON data
          topojsonData.objects['gujarat'], // The specific object within the TopoJSON
          (a, b) => a !== b, // Function to determine which borders to include; in this case, interior borders only
        ),
      });
    });
  }, []); // An empty dependency array ensures this effect runs only once after the initial render

  // Return the processed data so it can be used by the component that utilizes this hook
  return data;
};
